@@ -16,6 +16,15 @@ BUYBACKPROGRAM_PRICE_AGE_WARNING_LIMIT = clean_setting(
     "BUYBACKPROGRAM_PRICE_AGE_WARNING_LIMIT", 48
 )
 
+# Unused tracking purge limit
+BUYBACKPROGRAM_UNUSED_TRACKING_PURGE_LIMIT = clean_setting(
+    "BUYBACKPROGRAM_UNUSED_TRACKING_PURGE_LIMIT", 48
+)
+
+BUYBACKPROGRAM_TRACK_PREFILL_CONTRACTS = clean_setting(
+    "BUYBACKPROGRAM_TRACK_PREFILL_CONTRACTS", True
+)
+
 # Tracking number tag
 BUYBACKPROGRAM_TRACKING_PREFILL = clean_setting(
     "BUYBACKPROGRAM_TRACKING_PREFILL", "aa-bbp"
