@@ -6,7 +6,6 @@ from django.core.exceptions import ValidationError
 from django.core.validators import MaxValueValidator, MinValueValidator
 from django.db import Error, models
 from django.utils.translation import gettext as _
-from esi.clients import EsiClientProvider
 from esi.errors import TokenExpiredError, TokenInvalidError
 from esi.models import Token
 from eveuniverse.models import EveEntity, EveSolarSystem, EveType
@@ -306,11 +305,7 @@ class Owner(models.Model):
                 # Prepare objects for bulk create
                 for item in contract_items:
                     cont = Contract.objects.get(contract_id=contract["contract_id"])
-                    try:
-                        itm = EveType.objects.get(pk=item["type_id"])
-                    except EveType.DoesNotExist:
-                        itm = EveType.objects.get_or_create(id=item["type_id"])
-                        itm = EveType.objects.get(pk=item["type_id"])
+                    itm, _ = EveType.objects.get_or_create_esi(id=item["type_id"])
 
                     contract_item = ContractItem(
                         contract=cont,
@@ -592,12 +587,7 @@ class Owner(models.Model):
                 # Prepare objects for bulk create
                 for item in contract_items:
                     cont = Contract.objects.get(contract_id=contract["contract_id"])
-
-                    try:
-                        itm = EveType.objects.get(pk=item["type_id"])
-                    except EveType.DoesNotExist:
-                        itm = EveType.objects.get_or_create(id=item["type_id"])
-                        itm = EveType.objects.get(pk=item["type_id"])
+                    itm, _ = EveType.objects.get_or_create_esi(id=item["type_id"])
 
                     contract_item = ContractItem(
                         contract=cont,
@@ -647,7 +637,6 @@ class Owner(models.Model):
 
     @fetch_token_for_owner(["esi-universe.read_structures.v1"])
     def _get_location_name(self, token, structid) -> list:
-        esi = EsiClientProvider()
         status = fetch_esi_status()
 
         if not status.is_online or status.error_limit_remain < 5:
